@@ -29,7 +29,7 @@ class SelfNodeRemediationTemplate(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             _spec = self.res["spec"] = {"template": {"spec": {}}}
 
             if self.remediation_strategy:
