@@ -1,13 +1,18 @@
 import pytest
+from fake_kubernetes_client import FakeDynamicClient
 from ocp_resources.csi_driver import CSIDriver
 
 
 @pytest.mark.incremental
 class TestCSIDriver:
     @pytest.fixture(scope="class")
-    def csidriver(self, fake_client):
+    def client(self):
+        return FakeDynamicClient()
+
+    @pytest.fixture(scope="class")
+    def csidriver(self, client):
         return CSIDriver(
-            client=fake_client,
+            client=client,
             name="test-csidriver",
         )
 
