@@ -1,13 +1,18 @@
 import pytest
+from fake_kubernetes_client import FakeDynamicClient
 from ocp_resources.operator import Operator
 
 
 @pytest.mark.incremental
 class TestOperator:
     @pytest.fixture(scope="class")
-    def operator(self, fake_client):
+    def client(self):
+        return FakeDynamicClient()
+
+    @pytest.fixture(scope="class")
+    def operator(self, client):
         return Operator(
-            client=fake_client,
+            client=client,
             name="test-operator",
         )
 
